'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _superficial = require('superficial');

var _superficial2 = _interopRequireDefault(_superficial);

var _Breakpoint = require('./Breakpoint');

var _Breakpoint2 = _interopRequireDefault(_Breakpoint);

var _colors = require('../colors');

var _colors2 = _interopRequireDefault(_colors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var pctOf = function pctOf(n, min, max) {
  return (n - min) / (max - min) * 100;
};

function LookBar(_ref, looks) {
  var prop = _ref.prop,
      value = _ref.value,
      min = _ref.min,
      max = _ref.max,
      width = _ref.width;

  var breakpoints = Object.keys(value).sort(function (a, b) {
    return a - b;
  });
  var minPct = pctOf(breakpoints[0], min, max);
  var maxPct = pctOf(breakpoints[breakpoints.length - 1], min, max);
  var labelPct = Math.max(Math.min(pctOf(width, min, max), maxPct), minPct);

  var left = Math.max(minPct, 0) + '%';
  var right = 100 - Math.min(maxPct, 100) + '%';
  var marginLeft = labelPct + '%';

  return _react2.default.createElement(
    'div',
    { looks: looks.container },
    _react2.default.createElement('div', {
      looks: looks.line,
      style: { left: left, right: right, background: (0, _colors2.default)(prop) }
    }),
    _react2.default.createElement(
      'div',
      { looks: looks.label, style: { marginLeft: marginLeft } },
      (0, _superficial.interpolate)({ val: value })(width).val
    ),
    breakpoints.filter(function (b) {
      return b <= max && b >= min;
    }).map(function (breakpoint) {
      return _react2.default.createElement(_Breakpoint2.default, _extends({
        key: breakpoint
      }, { breakpoint: breakpoint, min: min, max: max }));
    })
  );
}

LookBar.looks = {
  container: { position: 'relative', paddingTop: '13px' },
  line: {
    position: 'absolute',
    top: '5px',
    height: 2
  },
  label: {
    transform: 'translateY(-2px)',
    wordWrap: 'break-word'
  }
};

LookBar.propTypes = {
  prop: _react2.default.PropTypes.string,
  value: _react2.default.PropTypes.object.isRequired,
  width: _react2.default.PropTypes.number,
  min: _react2.default.PropTypes.number,
  max: _react2.default.PropTypes.number
};

exports.default = (0, _superficial2.default)(LookBar);